@@ -37,7 +37,7 @@ K_PLUGIN_FACTORY_WITH_JSON(KateFileTreeFactory, "katefiletreeplugin.json", regis
 Q_LOGGING_CATEGORY(FILETREE, "kate-filetree", QtWarningMsg)
 
 // BEGIN KateFileTreePlugin
-KateFileTreePlugin::KateFileTreePlugin(QObject *parent, const QVariantList &)
+KateFileTreePlugin::KateFileTreePlugin(QObject *parent)
     : KTextEditor::Plugin(parent)
 {
 }
@@ -459,8 +459,6 @@ void KateFileTreePluginView::writeSessionConfig(KConfigGroup &g)
         g.deleteEntry("listMode");
         g.deleteEntry("sortRole");
     }
-
-    g.sync();
 }
 
 void KateFileTreePluginView::slotDocumentsCreated()
