@@ -16,6 +16,8 @@
 
 #include <optional>
 
+#include <exec_utils.h>
+
 class QPushButton;
 class QComboBox;
 class QFrame;
@@ -52,8 +54,10 @@ struct GDBTargetConf {
 
 struct DAPAdapterSettings {
     int index{};
+    // profile object = merged run/configuration
     QJsonObject settings;
     QStringList variables;
+    Utils::PathMappingPtr pathMap;
 };
 
 struct DAPTargetConf {
@@ -79,7 +83,7 @@ public:
     /**
      * When `full` is true, a DAP launch request will be computed.
      */
-    const DAPTargetConf currentDAPTarget(bool full = false) const;
+    DAPTargetConf currentDAPTarget(bool full, QString &errorMessage) const;
     bool takeFocusAlways() const;
     bool showIOTab() const;
     QUrl dapConfigPath;
@@ -149,7 +153,9 @@ private:
     QLabel *m_processIdLabel;
     KSelectAction *m_targetSelectAction = nullptr;
 
+    // (var name, Field)
     QHash<QString, Field> m_dapFields;
+    // (server, (profile, settings))
     QHash<QString, QHash<QString, DAPAdapterSettings>> m_dapAdapterSettings;
 
     QUrl m_dapConfigPath;
