@@ -26,11 +26,9 @@
 #include <QKeySequence>
 #include <QLayout>
 #include <QPainter>
-#include <QUrl>
-#include <QVariant>
 #include <QtMath>
 
-static bool isUncomittedLine(const QByteArray &hash)
+static bool isUncomittedLine(QByteArrayView hash)
 {
     return hash == "hash" || hash == "0000000000000000000000000000000000000000";
 }
@@ -54,7 +52,7 @@ QList<int> GitBlameInlineNoteProvider::inlineNotes(int line) const
         return QList<int>();
     }
 
-    QPointer<KTextEditor::Document> doc = m_pluginView->activeDocument();
+    KTextEditor::Document *doc = m_pluginView->activeDocument();
     if (!doc) {
         return QList<int>();
     }
@@ -64,7 +62,7 @@ QList<int> GitBlameInlineNoteProvider::inlineNotes(int line) const
     }
 
     int lineLen = doc->line(line).size();
-    QPointer<KTextEditor::View> view = m_pluginView->activeView();
+    KTextEditor::View *view = m_pluginView->activeView();
     if (view->cursorPosition().line() == line || m_mode == KateGitBlameMode::AllLines) {
         return QList<int>{lineLen + 4};
     }
@@ -161,7 +159,7 @@ void GitBlameInlineNoteProvider::setMode(KateGitBlameMode mode)
 
 K_PLUGIN_FACTORY_WITH_JSON(KateGitBlamePluginFactory, "kategitblameplugin.json", registerPlugin<KateGitBlamePlugin>();)
 
-KateGitBlamePlugin::KateGitBlamePlugin(QObject *parent, const QVariantList &)
+KateGitBlamePlugin::KateGitBlamePlugin(QObject *parent)
     : KTextEditor::Plugin(parent)
 {
 }
@@ -206,9 +204,14 @@ KateGitBlamePluginView::KateGitBlamePluginView(KateGitBlamePlugin *plugin, KText
     m_startBlameTimer.setInterval(400);
     m_startBlameTimer.callOnTimeout(this, &KateGitBlamePluginView::startGitBlameForActiveView);
 
-    connect(m_mainWindow, &KTextEditor::MainWindow::viewChanged, this, [this](KTextEditor::View *) {
-        m_startBlameTimer.start();
+    connect(m_mainWindow, &KTextEditor::MainWindow::viewChanged, this, [this]() {
+        if (!activeView()) {
+            return;
+        }
 
+        QObject::disconnect(m_documentReloadConnection);
+        m_documentReloadConnection = connect(activeDocument(), &KTextEditor::Document::reloaded, this, &KateGitBlamePluginView::documentReloaded);
+        m_startBlameTimer.start();
         m_tooltip.hide();
     });
 
@@ -232,12 +235,21 @@ KateGitBlamePluginView::~KateGitBlamePluginView()
     m_mainWindow->guiFactory()->removeClient(this);
 }
 
-QPointer<KTextEditor::View> KateGitBlamePluginView::activeView() const
+void KateGitBlamePluginView::documentReloaded()
+{
+    // We need to clear the m_absoluteFilePath as it is used to prevent re-parsing the same blame
+    // in different split views
+    m_absoluteFilePath.clear();
+    m_startBlameTimer.start();
+    m_tooltip.hide();
+}
+
+KTextEditor::View *KateGitBlamePluginView::activeView() const
 {
     return m_mainWindow->activeView();
 }
 
-QPointer<KTextEditor::Document> KateGitBlamePluginView::activeDocument() const
+KTextEditor::Document *KateGitBlamePluginView::activeDocument() const
 {
     KTextEditor::View *view = m_mainWindow->activeView();
     if (view && view->document()) {
@@ -280,8 +292,7 @@ void KateGitBlamePluginView::startBlameProcess(const QUrl &url)
     m_absoluteFilePath = fi.absoluteFilePath();
 
     // clear everything
-    m_blamedLines.clear();
-    m_blameInfoForHash.clear();
+    m_parser.clear();
 
     // Kill any existing process...
     if (m_blameInfoProc.state() != QProcess::NotRunning) {
@@ -317,21 +328,6 @@ void KateGitBlamePluginView::showCommitInfo(const QString &hash, KTextEditor::Vi
     startShowProcess(view->document()->url(), hash);
 }
 
-static int nextBlockStart(const QByteArray &out, int from)
-{
-    int next = out.indexOf('\t', from);
-    // tab must be the first character in line for next block
-    if (next > 0 && out[next - 1] != '\n') {
-        next++;
-        // move forward one line
-        next = out.indexOf('\n', next);
-        // try to look for another tab char
-        next = out.indexOf('\t', next);
-        // if not found => end
-    }
-    return next;
-}
-
 void KateGitBlamePluginView::sendMessage(const QString &text, bool error)
 {
     Utils::showMessage(text, gitIcon(), i18n("Git"), error ? MessageType::Error : MessageType::Info, m_mainWindow);
@@ -389,126 +385,8 @@ void KateGitBlamePluginView::commandFinished(int exitCode, QProcess::ExitStatus
 
 void KateGitBlamePluginView::parseGitBlameStdOutput()
 {
-    QByteArray out = m_blameInfoProc.readAllStandardOutput();
-    out.replace("\r", ""); // KTextEditor removes all \r characters in the internal buffers
-    // printf("recieved output: %d for: git %s\n", out.size(), qPrintable(m_blameInfoProc.arguments().join(QLatin1Char(' '))));
-
-    /**
-     * This is out git blame output parser.
-     *
-     * The output contains info about each line of text and commit info
-     * for that line. We store the commit info separately in a hash-map
-     * so that they don't need to be duplicated. For each line we store
-     * its line text and short commit. Text is needed because if you
-     * modify the doc, we use it to figure out where the original blame
-     * line is. The short commit is used to fetch the full commit from
-     * the hashmap
-     */
-
-    int start = 0;
-    int next = out.indexOf('\t');
-    next = out.indexOf('\n', next);
-
-    while (next != -1) {
-        //         printf("Block: (Size: %d) %s\n\n", (next - start), out.mid(start, next - start).constData());
-
-        CommitInfo commitInfo;
-        BlamedLine lineInfo;
-
-        /**
-         * Parse hash and line numbers
-         *
-         * 5c7f27a0915a9b20dc9f683d0d85b6e4b829bc85 1 1 5
-         */
-        int pos = out.indexOf(' ', start);
-        constexpr int hashLen = 40;
-        if (pos == -1 || (pos - start) != hashLen) {
-            printf("no proper hash\n");
-            break;
-        }
-        QByteArray hash = out.mid(start, pos - start);
-
-        // skip to line end,
-        // we don't care about line no etc here
-        int from = pos + 1;
-        pos = out.indexOf('\n', from);
-        if (pos == -1) {
-            qWarning() << "Git blame: Invalid blame output : No new line";
-            break;
-        }
-        pos++;
-
-        lineInfo.shortCommitHash = hash.mid(0, 7);
-
-        m_blamedLines.push_back(lineInfo);
-
-        // are we done because this line references the commit instead of
-        // containing the content?
-        if (out[pos] == '\t') {
-            pos++; // skip \t
-            from = pos;
-            pos = out.indexOf('\n', from); // go to line end
-            m_blamedLines.back().lineText = out.mid(from, pos - from);
-
-            start = next + 1;
-            next = nextBlockStart(out, start);
-            if (next == -1)
-                break;
-            next = out.indexOf('\n', next);
-            continue;
-        }
-
-        /**
-         * Parse actual commit
-         */
-        commitInfo.hash = hash;
-
-        // author Xyz
-        constexpr int authorLen = sizeof("author ") - 1;
-        pos += authorLen;
-        from = pos;
-        pos = out.indexOf('\n', pos);
-
-        commitInfo.authorName = QString::fromUtf8(out.mid(from, pos - from));
-        pos++;
-
-        // author-time timestamp
-        constexpr int authorTimeLen = sizeof("author-time ") - 1;
-        pos = out.indexOf("author-time ", pos);
-        if (pos == -1) {
-            qWarning() << "Invalid commit while git-blameing";
-            break;
-        }
-        pos += authorTimeLen;
-        from = pos;
-        pos = out.indexOf('\n', from);
-
-        qint64 timestamp = out.mid(from, pos - from).toLongLong();
-        commitInfo.authorDate = QDateTime::fromSecsSinceEpoch(timestamp);
-
-        constexpr int summaryLen = sizeof("summary ") - 1;
-        pos = out.indexOf("summary ", pos);
-        pos += summaryLen;
-        from = pos;
-        pos = out.indexOf('\n', pos);
-
-        commitInfo.summary = out.mid(from, pos - from);
-        //         printf("Commit{\n %s,\n %s,\n %s,\n %s\n}\n", qPrintable(commitInfo.commitHash), qPrintable(commitInfo.name),
-        //         qPrintable(commitInfo.date.toString()), qPrintable(commitInfo.title));
-
-        m_blameInfoForHash[lineInfo.shortCommitHash] = commitInfo;
-
-        from = pos;
-        pos = out.indexOf('\t', from);
-        from = pos + 1;
-        pos = out.indexOf('\n', from);
-        m_blamedLines.back().lineText = out.mid(from, pos - from);
-
-        start = next + 1;
-        next = nextBlockStart(out, start);
-        if (next == -1)
-            break;
-        next = out.indexOf('\n', next);
+    if (!m_parser.parseGitBlame(m_blameInfoProc.readAllStandardOutput())) {
+        qWarning() << "Failed to parse git-blame";
     }
 }
 
@@ -534,14 +412,14 @@ void KateGitBlamePluginView::showFinished(int exitCode, QProcess::ExitStatus exi
     for (int i = 0; i < 4; ++i) {
         titleStart = stdOut.indexOf(QLatin1Char('\n'), titleStart + 1);
         if (titleStart < 0 || titleStart >= stdOut.size() - 1) {
-            qWarning() << "This is not a known git show format";
+            qWarning("This is not a known git show format");
             return;
         }
     }
 
     int titleEnd = stdOut.indexOf(QLatin1Char('\n'), titleStart + 1);
     if (titleEnd < 0 || titleEnd >= stdOut.size() - 1) {
-        qWarning() << "This is not a known git show format";
+        qWarning("This is not a known git show format");
         return;
     }
 
@@ -567,56 +445,43 @@ void KateGitBlamePluginView::showFinished(int exitCode, QProcess::ExitStatus exi
 
 bool KateGitBlamePluginView::hasBlameInfo() const
 {
-    return !m_blamedLines.empty();
+    return m_parser.hasBlameInfo();
 }
 
 const CommitInfo &KateGitBlamePluginView::blameInfo(int lineNr)
 {
-    if (m_blamedLines.empty() || m_blameInfoForHash.isEmpty() || !activeDocument()) {
-        return blameGetUpdateInfo(-1);
+    if (!m_parser.hasBlameInfo() || !activeDocument()) {
+        return m_parser.blameLineInfo(-1);
     }
 
-    const int totalBlamedLines = (int)m_blamedLines.size();
+    const int totalBlamedLines = m_parser.blameLineCount();
     const int adjustedLineNr = lineNr + m_lineOffset;
     const QByteArray lineText = activeDocument()->line(lineNr).toUtf8();
 
     if (adjustedLineNr >= 0 && adjustedLineNr < totalBlamedLines) {
-        if (m_blamedLines[adjustedLineNr].lineText == lineText) {
-            return blameGetUpdateInfo(adjustedLineNr);
+        if (m_parser.blameLine(adjustedLineNr) == lineText) {
+            return m_parser.blameLineInfo(adjustedLineNr);
         }
     }
 
     // search for the line 100 lines before and after until it matches
     m_lineOffset = 0;
     while (m_lineOffset < 100 && lineNr + m_lineOffset >= 0 && lineNr + m_lineOffset < totalBlamedLines) {
-        if (m_blamedLines[lineNr + m_lineOffset].lineText == lineText) {
-            return blameGetUpdateInfo(lineNr + m_lineOffset);
+        if (m_parser.blameLine(lineNr + m_lineOffset) == lineText) {
+            return m_parser.blameLineInfo(lineNr + m_lineOffset);
         }
         m_lineOffset++;
     }
 
     m_lineOffset = 0;
     while (m_lineOffset > -100 && lineNr + m_lineOffset >= 0 && (lineNr + m_lineOffset) < totalBlamedLines) {
-        if (m_blamedLines[lineNr + m_lineOffset].lineText == lineText) {
-            return blameGetUpdateInfo(lineNr + m_lineOffset);
+        if (m_parser.blameLine(lineNr + m_lineOffset) == lineText) {
+            return m_parser.blameLineInfo(lineNr + m_lineOffset);
         }
         m_lineOffset--;
     }
 
-    return blameGetUpdateInfo(-1);
-}
-
-const CommitInfo &KateGitBlamePluginView::blameGetUpdateInfo(int lineNr)
-{
-    static const CommitInfo dummy{.hash = "hash", .authorName = i18n("Not Committed Yet"), .authorDate = QDateTime::currentDateTime(), .summary = {}};
-    if (m_blamedLines.empty() || lineNr < 0 || lineNr >= (int)m_blamedLines.size()) {
-        return dummy;
-    }
-
-    auto &commitInfo = m_blamedLines[lineNr];
-
-    Q_ASSERT(m_blameInfoForHash.contains(commitInfo.shortCommitHash));
-    return m_blameInfoForHash[commitInfo.shortCommitHash];
+    return m_parser.blameLineInfo(-1);
 }
 
 void KateGitBlamePluginView::setToolTipIgnoreKeySequence(const QKeySequence &sequence)
@@ -635,7 +500,6 @@ void KateGitBlamePluginView::onErrorOccurred(QProcess::ProcessError e)
 {
     auto process = qobject_cast<QProcess *>(sender());
     if (process) {
-        qWarning() << process->program() << process->arguments() << "Failed to start with error: " << e;
         sendMessage(QStringLiteral("%1 with args %2, error occurred: %3.").arg(process->program(), process->arguments().join(QLatin1Char(' '))).arg(e), false);
     }
 }
