@@ -227,8 +227,6 @@ void KateCTagsView::writeSessionConfig(KConfigGroup &cg)
     }
 
     cg.writeEntry("SessionDatabase", m_ctagsUi.tagsFile->text());
-
-    cg.sync();
 }
 
 /******************************************************************/
@@ -392,7 +390,7 @@ QString KateCTagsView::currentWord()
 {
     KTextEditor::View *kv = m_mWin->activeView();
     if (!kv) {
-        qCDebug(KTECTAGS) << "no KTextEditor::View";
+        qCDebug(KTECTAGS, "no KTextEditor::View");
         return QString();
     }
 
@@ -401,7 +399,7 @@ QString KateCTagsView::currentWord()
     }
 
     if (!kv->cursorPosition().isValid()) {
-        qCDebug(KTECTAGS) << "cursor not valid!";
+        qCDebug(KTECTAGS, "cursor not valid!");
         return QString();
     }
 
@@ -423,7 +421,7 @@ QString KateCTagsView::currentWord()
         endPos++;
     }
     if (startPos == endPos) {
-        qCDebug(KTECTAGS) << "no word found!";
+        qCDebug(KTECTAGS, "no word found!");
         return QString();
     }
 
