@@ -8,10 +8,9 @@
 
 class ConnectionModel;
 class KConfigGroup;
-class QUrl;
 
 #include "connection.h"
-#include <KWallet>
+
 #include <QSqlQuery>
 #include <QUrl>
 
@@ -28,7 +27,6 @@ public:
     static bool testConnection(const Connection &conn, QSqlError &error);
     bool isValidAndOpen(const QString &connection);
 
-    KWallet::Wallet *openWallet();
     int storeCredentials(const Connection &conn);
     int readCredentials(const QString &name, QString &password);
     static const int K_WALLET_CONNECTION_SUCCESSFUL = 0;
@@ -57,5 +55,4 @@ Q_SIGNALS:
 
 private:
     ConnectionModel *m_model;
-    KWallet::Wallet *m_wallet = nullptr;
 };
