@@ -37,7 +37,7 @@ public:
 private:
     void doSemanticHighlighting_impl(KTextEditor::View *v);
 
-    void semanticHighlightRange(KTextEditor::View *view, const KTextEditor::Cursor &);
+    Q_SLOT void highlightVisibleRange();
 
     QString previousResultIdForDoc(KTextEditor::Document *doc) const;
 
@@ -69,7 +69,7 @@ private:
     KTextEditor::Range m_currentHighlightedRange;
 
     /**
-     * A simple struct which holds the tokens recieved from server +
+     * A simple struct which holds the tokens received from server +
      * moving ranges that were created to highlight those tokens
      */
     struct TokensData {
@@ -96,4 +96,6 @@ private:
 
     QTimer m_requestTimer;
     QPointer<KTextEditor::View> m_currentView;
+
+    QMetaObject::Connection m_verticalScrollConnection;
 };
