@@ -144,27 +144,33 @@ void PreviewWidget::setTextEditorView(KTextEditor::View *view)
 std::optional<KPluginMetaData> KTextEditorPreview::PreviewWidget::findPreviewPart(const QStringList &mimeTypes)
 {
     for (const auto &mimeType : std::as_const(mimeTypes)) {
+        // Skip text/plain. Kate can display it just fine ;)
+        if (mimeType == QLatin1String("text/plain")) {
+            continue;
+        }
+
         const auto offers = KParts::PartLoader::partsForMimeType(mimeType);
 
         if (offers.isEmpty()) {
             continue;
         }
 
-        const KPluginMetaData &service = offers.first();
-        qCDebug(KTEPREVIEW) << "Found preferred kpart named" << service.name() << "with library" << service.fileName() << "for mimetype" << mimeType;
+        for (const auto &offer : offers) {
+            // Skip katepart, we already are in one ;)
+            if (offer.pluginId() == QLatin1String("katepart")) {
+                continue;
+            }
 
-        // no interest in kparts which also just display the text (like katepart itself)
-        // TODO: what about parts which also support importing plain text and turning into richer format
-        // and thus have it in their mimetypes list?
-        // could that perhaps be solved by introducing the concept of "native" and "imported" mimetypes?
-        // or making a distinction between source editors/viewers and final editors/viewers?
-        // latter would also help other source editors/viewers like a hexeditor, which "supports" any mimetype
-        if (service.mimeTypes().contains(QLatin1String("text/plain"))) {
-            qCDebug(KTEPREVIEW) << "Blindly discarding preferred kpart as it also supports text/plain, to avoid useless plain/text preview.";
-            continue;
+            qCDebug(KTEPREVIEW,
+                    "Found preferred kpart named %ls with library %ls for mimetype %ls",
+                    qUtf16Printable(offer.name()),
+                    qUtf16Printable(offer.fileName()),
+                    qUtf16Printable(mimeType));
+
+            // TODO: add a part preference list, perhaps hardcoded initially. For e.g., for markdown
+            // it should prefer to use markdownpart first then okularpart
+            return offer;
         }
-
-        return service;
     }
     return {};
 }
@@ -184,14 +190,15 @@ void PreviewWidget::resetTextEditorView(KTextEditor::Document *document)
 
         // Get mimetypes assigned to the currently set mode.
         auto mimeTypes = KConfigGroup(KSharedConfig::openConfig(QStringLiteral("katemoderc")), m_currentMode).readXdgListEntry("Mimetypes");
-        // For markdown manually add text/markdown if above fails e.g., if the file is untitled
-        if (mimeTypes.isEmpty() && m_currentMode == QStringLiteral("Markdown")) {
-            mimeTypes << QStringLiteral("text/markdown");
-        }
 
         // Also try to guess from the content, if the above fails.
         mimeTypes << m_previewedTextEditorDocument->mimeType();
 
+        // For markdown manually add text/markdown if above fails e.g., if the file is untitled
+        if (mimeTypes.isEmpty() && m_currentMode == QStringLiteral("Markdown") && !mimeTypes.contains(u"text/markdown")) {
+            mimeTypes << QStringLiteral("text/markdown");
+        }
+
         service = findPreviewPart(mimeTypes);
 
         if (!service) {
@@ -224,7 +231,7 @@ void PreviewWidget::resetTextEditorView(KTextEditor::Document *document)
         m_currentServiceId = serviceId;
 
         if (service) {
-            qCDebug(KTEPREVIEW) << "Creating new kpart service instance.";
+            qCDebug(KTEPREVIEW, "Creating new kpart service instance.");
             m_partView = new KPartView(*service, this);
             const bool autoupdate = m_autoUpdateAction->isChecked();
             m_partView->setAutoUpdating(autoupdate);
@@ -248,7 +255,7 @@ void PreviewWidget::resetTextEditorView(KTextEditor::Document *document)
             m_partView = nullptr;
         }
     } else if (m_partView) {
-        qCDebug(KTEPREVIEW) << "Reusing active kpart service instance.";
+        qCDebug(KTEPREVIEW, "Reusing active kpart service instance.");
     }
 
     if (m_partView) {
