@@ -193,7 +193,7 @@ void KateProjectCompletion::allMatches(QStandardItemModel &model, KTextEditor::V
     /**
      * let project index fill the completion for this document
      */
-    for (const auto project : qAsConst(projects)) {
+    for (const auto project : std::as_const(projects)) {
         if (project->projectIndex()) {
             project->projectIndex()->findMatches(model, view->document()->text(range), KateProjectIndex::CompletionMatches);
         }
