@@ -5,8 +5,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KATE_PROJECT_INFO_VIEW_TERMINAL_H
-#define KATE_PROJECT_INFO_VIEW_TERMINAL_H
+#pragma once
 
 #include <QKeyEvent>
 #include <QVBoxLayout>
@@ -83,6 +82,11 @@ private:
      */
     static KPluginFactory *pluginFactory();
 
+    bool hasKonsole() const
+    {
+        return pluginFactory() != nullptr;
+    }
+
 private:
     /**
      * plugin factory for the terminal
@@ -107,9 +111,7 @@ private:
     /**
      * konsole part
      */
-    KParts::ReadOnlyPart *m_konsolePart;
+    KParts::ReadOnlyPart *m_konsolePart = nullptr;
 
     QPointer<QAction> m_showProjectInfoViewAction;
 };
-
-#endif
