@@ -7,10 +7,7 @@
 
 #pragma once
 
-#include <QComboBox>
-#include <QMenu>
 #include <QPointer>
-#include <QStackedWidget>
 #include <QToolButton>
 
 #include <KTextEditor/View>
@@ -18,17 +15,15 @@
 
 #include <memory>
 
-#include <kateprojectview.h>
-
 class QAction;
 class QDir;
 class KateProject;
 class KateProjectPlugin;
 class KateProjectInfoView;
+class KateProjectView;
 class GitWidget;
-
-typedef QMap<QString, QString> QStringMap;
-Q_DECLARE_METATYPE(QStringMap)
+class QComboBox;
+class QStackedWidget;
 
 class KateProjectPluginView : public QObject, public KXMLGUIClient
 {
@@ -42,7 +37,7 @@ class KateProjectPluginView : public QObject, public KXMLGUIClient
 
     Q_PROPERTY(QString allProjectsCommonBaseDir READ allProjectsCommonBaseDir)
     Q_PROPERTY(QStringList allProjectsFiles READ allProjectsFiles)
-    Q_PROPERTY(QStringMap allProjects READ allProjects)
+    Q_PROPERTY(QMap<QString, QString> allProjects READ allProjects)
 
 public:
     KateProjectPluginView(KateProjectPlugin *plugin, KTextEditor::MainWindow *mainWindow);
@@ -94,6 +89,11 @@ public:
      */
     QMap<QString, QString> allProjects() const;
 
+    /**
+     * @returns the project map of the specified base directory (base directory is unique)
+     */
+    Q_INVOKABLE QVariantMap projectMapFor(const QString &baseDir) const;
+
     /**
      * the main window we belong to
      * @return our main window
@@ -127,14 +127,18 @@ public:
      */
     GitWidget *gitWidget();
 
+    /**
+     * Runs the given @p cmd in active project's terminal
+     */
+    void runCmdInTerminal(const QString &cmd);
+
 public Q_SLOTS:
     /**
      * Create views for given project.
      * Either gives existing ones or creates new one
      * @param project project we want view for
-     * @return views (normal + info view)
      */
-    QPair<KateProjectView *, KateProjectInfoView *> viewForProject(KateProject *project);
+    void viewForProject(KateProject *project);
 
     /**
      * Switch to project for given dir, if any there!
@@ -249,11 +253,16 @@ Q_SIGNALS:
     void projectLookupWord(const QString &word);
 
     /**
-     * Emitted when a ctags goto sysmbol is requested
+     * Emitted when a ctags goto symbol is requested
      * @param word lookup word
      */
     void gotoSymbol(const QString &word, int &results);
 
+    /**
+     * Emitted if projectMap was edited.
+     */
+    void projectMapEdited();
+
 private Q_SLOTS:
     /**
      * This slot is called whenever the active view changes in our main window.
@@ -377,10 +386,14 @@ private:
 
     GitWidget *m_gitWidget;
 
+    struct ProjectViews {
+        KateProjectView *tree;
+        KateProjectInfoView *infoview;
+    };
     /**
      * project => view
      */
-    QMap<KateProject *, QPair<KateProjectView *, KateProjectInfoView *>> m_project2View;
+    QMap<KateProject *, ProjectViews> m_project2View;
 
     /**
      * remember current active view text editor view
