@@ -283,7 +283,7 @@ QStandardItem *KateProjectViewTree::unflattenTreeAndReturnClickedItem(const QMod
     auto index = proxyModel->mapToSource(idx);
     auto item = m_project->model()->itemFromIndex(index);
 
-    if (active.index < splitted.size() - 1) {
+    if (active.index < splitted.size() - 1 && active.index >= 0) {
         QString path = item->data(Qt::UserRole).toString();
         QList<QStandardItem *> items;
         for (int i = splitted.size() - 1; i > 0; i--) {
@@ -550,7 +550,10 @@ void KateProjectViewTree::flattenPath(const QModelIndex &index)
         auto child = item->child(0);
         if (child && child->type() == KateProjectItem::Directory) {
             item->takeColumn(0);
-            item->appendColumn(child->takeColumn(0));
+            const auto childColumn0 = child->takeColumn(0);
+            if (!childColumn0.isEmpty()) {
+                item->appendColumn(childColumn0);
+            }
 
             // Set the path to child's path
             item->setData(child->data(Qt::UserRole), Qt::UserRole);
