@@ -14,11 +14,7 @@ class ResultsTreeView : public QTreeView
 public:
     ResultsTreeView(QWidget *parent);
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QStyleOptionViewItem viewOptions() const override;
-#else
     void initViewItemOption(QStyleOptionViewItem *option) const override;
-#endif
 
 private:
     QColor m_fg;
@@ -26,11 +22,7 @@ private:
 
 protected:
     void resizeEvent(QResizeEvent *) override;
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    void enterEvent(QEvent *event) override;
-#else
     void enterEvent(QEnterEvent *event) override;
-#endif
     void leaveEvent(QEvent *) override;
 
 Q_SIGNALS:
