@@ -16,6 +16,8 @@
 
 #include <algorithm>
 
+#include <ktexteditor_utils.h>
+
 namespace detail
 {
 FilenameListItem::FilenameListItem(DocOrWidget doc)
@@ -40,7 +42,7 @@ QString FilenameListItem::documentName() const
 
 QString FilenameListItem::fullPath() const
 {
-    return document.doc() ? document.doc()->url().toLocalFile() : QString();
+    return document.doc() ? Utils::formatUrl(document.doc()->url()) : QString();
 }
 
 /**
@@ -61,7 +63,7 @@ QString longestCommonPrefix(std::vector<QString> const &strs)
 
     for (int pos = 0; pos < n; pos++) { // check each character
         for (size_t i = 1; i < strs.size(); i++) {
-            if (strs[i][pos] != strs[i - 1][pos]) { // we found a mis-match
+            if (strs[i][pos] != strs[i - 1][pos]) { // we found a mismatch
                 // reverse search to find path separator
                 const int sepIndex = QStringView(strs.front()).left(pos).lastIndexOf(QLatin1Char('/'));
                 if (sepIndex >= 0) {
@@ -192,6 +194,9 @@ void detail::TabswitcherFilesModel::raiseDocument(DocOrWidget document)
 
 DocOrWidget detail::TabswitcherFilesModel::item(int row) const
 {
+    if (row < 0 || size_t(row) >= data_.size()) {
+        return DocOrWidget();
+    }
     return data_[row].document;
 }
 
@@ -201,20 +206,22 @@ void detail::TabswitcherFilesModel::updateItems()
     Q_EMIT dataChanged(createIndex(0, 0), createIndex((int)data_.size() - 1, 1), {});
 }
 
-int detail::TabswitcherFilesModel::columnCount(const QModelIndex &parent) const
+int detail::TabswitcherFilesModel::columnCount(const QModelIndex &) const
 {
-    Q_UNUSED(parent);
     return 2;
 }
 
-int detail::TabswitcherFilesModel::rowCount(const QModelIndex &parent) const
+int detail::TabswitcherFilesModel::rowCount(const QModelIndex &) const
 {
-    Q_UNUSED(parent);
     return (int)data_.size();
 }
 
 QVariant detail::TabswitcherFilesModel::data(const QModelIndex &index, int role) const
 {
+    if (!index.isValid() || index.row() < 0 || size_t(index.row()) >= data_.size()) {
+        return QVariant();
+    }
+
     if (role == Qt::DisplayRole) {
         const auto &row = data_[index.row()];
         if (index.column() == 0) {
