@@ -7,7 +7,6 @@
 #include "bytearraysplitter.h"
 
 #include <QTest>
-#include <iostream>
 
 QTEST_MAIN(ByteArraySplitterTests)
 
@@ -34,3 +33,5 @@ void ByteArraySplitterTests::test()
     }
     QCOMPARE(data.split(splitOn), actual);
 }
+
+#include "moc_bytearraysplitter_tests.cpp"
