@@ -8,7 +8,6 @@
 #include "diagnosticitem.h"
 #include "drawing_utils.h"
 #include "kateapp.h"
-#include "kateviewmanager.h"
 #include "session_diagnostic_suppression.h"
 #include "texthint/KateTextHintManager.h"
 
@@ -24,7 +23,6 @@
 #include <KXMLGUIFactory>
 #include <QClipboard>
 #include <QComboBox>
-#include <QDebug>
 #include <QFileInfo>
 #include <QGuiApplication>
 #include <QLineEdit>
@@ -38,6 +36,8 @@
 #include <QTreeView>
 #include <QVBoxLayout>
 
+#include <memory_resource>
+
 class ProviderListModel final : public QAbstractListModel
 {
 public:
@@ -92,14 +92,28 @@ public:
 
     void setActiveProvider(DiagnosticsProvider *provider)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         activeProvider = provider;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 
     void setActiveSeverity(DiagnosticSeverity s)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         severity = s;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 
     DiagnosticSeverity activeSeverity() const
@@ -540,14 +554,14 @@ void DiagnosticsView::onViewChanged(KTextEditor::View *v)
     }
 
     if (v && v->document()) {
-        connect(v->document(), &KTextEditor::Document::documentUrlChanged, m_urlChangedTimer, QOverload<>::of(&QTimer::start), Qt::UniqueConnection);
+        connect(v->document(), &KTextEditor::Document::documentUrlChanged, m_urlChangedTimer, qOverload<>(&QTimer::start), Qt::UniqueConnection);
     }
 }
 
 void DiagnosticsView::registerDiagnosticsProvider(DiagnosticsProvider *provider)
 {
     if (std::find(m_providers.begin(), m_providers.end(), provider) != m_providers.end()) {
-        qWarning() << provider << " already registred, ignoring!";
+        qWarning("already registered provider, ignoring!");
         return;
     }
 
@@ -627,8 +641,8 @@ void DiagnosticsView::tabForToolViewAdded(QWidget *toolView, QWidget *tab)
 
 static DocumentDiagnosticItem *getItem(const QStandardItemModel &model, const QUrl &url)
 {
-    // local file in custom role, Qt::DisplayRole might have additional elements
-    auto l = model.match(model.index(0, 0, QModelIndex()), Qt::UserRole, url.toString(QUrl::PreferLocalFile | QUrl::RemovePassword), 1, Qt::MatchExactly);
+    // url in custom role, Qt::DisplayRole might have additional elements
+    auto l = model.match(model.index(0, 0, QModelIndex()), Qt::UserRole, url, 1, Qt::MatchExactly);
     if (!l.empty()) {
         return static_cast<DocumentDiagnosticItem *>(model.itemFromIndex(l.at(0)));
     }
@@ -703,13 +717,13 @@ void DiagnosticsView::onFixesAvailable(const QList<DiagnosticFix> &fixes, const
     }
     const auto diagModelIdx = data.value<DiagModelIndex>();
     if (diagModelIdx.parentRow == -1) {
-        qWarning() << "Unexpected -1 parentRow";
+        qWarning("Unexpected -1 parentRow");
         return;
     }
     const auto parentIdx = m_model.index(diagModelIdx.parentRow, 0);
     const auto idx = m_model.index(diagModelIdx.row, 0, parentIdx);
     if (!idx.isValid()) {
-        qWarning() << Q_FUNC_INFO << "Unexpected invalid idx";
+        qWarning("%s, Unexpected invalid idx", Q_FUNC_INFO);
         return;
     }
     const auto item = m_model.itemFromIndex(idx);
@@ -795,7 +809,7 @@ void DiagnosticsView::onDoubleClicked(const QModelIndex &index, bool quickFix)
 {
     auto itemFromIndex = m_model.itemFromIndex(index);
     if (!itemFromIndex) {
-        qWarning() << "invalid item clicked";
+        qWarning("invalid item clicked");
         return;
     }
 
@@ -868,7 +882,7 @@ void DiagnosticsView::onDiagnosticsAdded(const FileDiagnostics &diagnostics)
         model->appendRow(topItem);
         QString prettyUri = diagnostics.uri.toString(QUrl::PreferLocalFile | QUrl::RemovePassword);
         topItem->setText(prettyUri);
-        topItem->setData(prettyUri, Qt::UserRole);
+        topItem->setData(diagnostics.uri, Qt::UserRole);
     } else {
         // try to retain current position
         auto currentIndex = m_proxy->mapToSource(m_diagnosticsTree->currentIndex());
@@ -959,7 +973,12 @@ static auto getProvider(QStandardItem *item)
     return item->data(DiagnosticModelRole::ProviderRole).value<DiagnosticsProvider *>();
 }
 
-void DiagnosticsView::clearDiagnosticsForStaleDocs(const QList<QString> &filesToKeep, DiagnosticsProvider *provider)
+void DiagnosticsView::clearDiagnosticsFromProvider(DiagnosticsProvider *provider)
+{
+    clearDiagnosticsForStaleDocs({}, provider);
+}
+
+void DiagnosticsView::clearDiagnosticsForStaleDocs(const std::pmr::unordered_set<QUrl, QUrlHash> &filesToKeep, DiagnosticsProvider *provider)
 {
     auto diagWarnShowGuard = qScopeGuard([this] {
         const bool diagnosticsAreLimited = m_diagnosticLimit > -1;
@@ -1004,7 +1023,7 @@ void DiagnosticsView::clearDiagnosticsForStaleDocs(const QList<QString> &filesTo
 
     for (int i = 0; i < m_model.rowCount(); ++i) {
         auto fileItem = static_cast<DocumentDiagnosticItem *>(m_model.item(i));
-        if (!filesToKeep.contains(fileItem->data(Qt::UserRole).toString())) {
+        if (!filesToKeep.contains(fileItem->data(Qt::UserRole).toUrl())) {
             if (!all_diags_from_provider(fileItem)) {
                 // If the diagnostics of this file item are from multiple providers
                 // delete the ones from @p provider
@@ -1119,12 +1138,12 @@ void DiagnosticsView::addMarks(KTextEditor::Document *doc, QStandardItem *item)
         break;
     }
     case DiagnosticSeverity::Unknown:
-        qWarning() << "Unknown diagnostic severity";
+        qWarning("Unknown diagnostic severity");
         return;
     }
 
     if (!attr) {
-        qWarning() << "Unexpected null attr";
+        qWarning("Unexpected null attr");
     }
 
     // highlight the range
@@ -1181,7 +1200,7 @@ void DiagnosticsView::addMarksRec(KTextEditor::Document *doc, QStandardItem *ite
 {
     Q_ASSERT(item);
     // We only care about @p doc items
-    if (item->type() == DiagnosticItem_File && QUrl::fromLocalFile(item->data(Qt::UserRole).toString()) != doc->url()) {
+    if (item->type() == DiagnosticItem_File && item->data(Qt::UserRole).toUrl() != doc->url()) {
         return;
     }
     addMarks(doc, item);
@@ -1220,7 +1239,7 @@ void DiagnosticsView::clearAllMarks(KTextEditor::Document *doc)
     }
 }
 
-void DiagnosticsView::updateMarks(const std::vector<QUrl> &urls)
+void DiagnosticsView::updateMarks(const std::span<QUrl> &urls)
 {
     std::vector<KTextEditor::Document *> docs;
     if (!urls.empty()) {
@@ -1281,7 +1300,7 @@ void DiagnosticsView::updateDiagnosticsState(DocumentDiagnosticItem *&topItem)
     }
     // adjust file item level text
     auto suppressed = totalCount - count;
-    const QString path = topItem->data(Qt::UserRole).toString();
+    const QString path = url.toString(QUrl::PreferLocalFile | QUrl::RemovePassword);
     topItem->setText(suppressed ? i18nc("@info", "%1 [suppressed: %2]", path, suppressed) : path);
     // only hide if really nothing below
     const auto proxyIdx = m_proxy->mapFromSource(topItem->index());
@@ -1291,7 +1310,8 @@ void DiagnosticsView::updateDiagnosticsState(DocumentDiagnosticItem *&topItem)
         topItem = nullptr;
     }
 
-    updateMarks({QUrl::fromLocalFile(path)});
+    QUrl urls[] = {QUrl::fromLocalFile(path)};
+    updateMarks(urls);
 }
 
 void DiagnosticsView::goToItemLocation(QModelIndex index)
@@ -1312,31 +1332,7 @@ void DiagnosticsView::goToItemLocation(QModelIndex index)
         return;
     }
 
-    int line = start.start().line();
-    int column = start.start().column();
-    KTextEditor::View *activeView = m_mainWindow->activeView();
-    if (line < 0 || column < 0) {
-        return;
-    }
-
-    KTextEditor::Document *document = activeView ? activeView->document() : nullptr;
-    KTextEditor::Cursor cdef(line, column);
-
-    KTextEditor::View *targetView = nullptr;
-    if (document && url == document->url()) {
-        targetView = activeView;
-    } else {
-        targetView = m_mainWindow->openUrl(url);
-    }
-    if (targetView) {
-        // save current position for location history
-        if (activeView) {
-            Utils::addPositionToHistory(activeView->document()->url(), activeView->cursorPosition(), m_mainWindow);
-        }
-        // save the position to which we are jumping in location history
-        Utils::addPositionToHistory(targetView->document()->url(), cdef, m_mainWindow);
-        targetView->setCursorPosition(cdef);
-    }
+    Utils::goToDocumentLocation(m_mainWindow, url, start);
 }
 
 void DiagnosticsView::onMarkClicked(KTextEditor::Document *document, KTextEditor::Mark mark, bool &handled)
@@ -1380,21 +1376,20 @@ bool DiagnosticsView::syncDiagnostics(KTextEditor::Document *document, KTextEdit
         targetItem = topItem;
     }
     if (targetItem) {
-        m_diagnosticsTree->blockSignals(true);
-        const auto idx = m_proxy->mapFromSource(targetItem->index());
-        if (idx.isValid()) {
+        if (const auto idx = m_proxy->mapFromSource(targetItem->index()); idx.isValid()) {
+            m_diagnosticsTree->blockSignals(true);
             m_diagnosticsTree->scrollTo(idx, hint);
             m_diagnosticsTree->setCurrentIndex(idx);
-        } else {
-            qWarning() << "Invalid idx for" << targetItem->text();
-            Q_ASSERT(false);
-        }
-        m_diagnosticsTree->blockSignals(false);
-        if (doShow) {
-            m_mainWindow->showToolView(qobject_cast<QWidget *>(parent()));
+            m_diagnosticsTree->blockSignals(false);
+
+            if (doShow) {
+                m_mainWindow->showToolView(qobject_cast<QWidget *>(parent()));
+            }
+
+            return true;
         }
     }
-    return targetItem != nullptr;
+    return false;
 }
 
 void DiagnosticsView::updateDiagnosticsSuppression(DocumentDiagnosticItem *diagTopItem, KTextEditor::Document *doc, bool force)
@@ -1485,7 +1480,7 @@ void DiagnosticsView::onContextMenuRequested(const QPoint &pos)
             } else {
                 menu->addAction(i18n("Add Global Suppression"), this, std::bind(h, true, empty, diagText));
             }
-            auto file = parent.data(Qt::UserRole).toString();
+            auto file = parent.data(Qt::UserRole).toUrl().toLocalFile();
             if (m_sessionDiagnosticSuppressions->hasSuppression(file, diagText)) {
                 menu->addAction(i18n("Remove Local Suppression"), this, std::bind(h, false, file, diagText));
             } else {
@@ -1550,14 +1545,17 @@ void DiagnosticsView::onDocumentUrlChanged()
 {
     // remove lingering diagnostics
     // collect active urls
-    QSet<QString> fpaths;
+    std::byte buffer[128 * 1000];
+    std::pmr::monotonic_buffer_resource memory(buffer, sizeof(buffer));
+    std::pmr::unordered_set<QUrl, QUrlHash> fpaths(&memory);
+
     const auto views = m_mainWindow->views();
     for (const auto view : views) {
         if (auto doc = view->document()) {
-            fpaths.insert(doc->url().toLocalFile());
+            fpaths.insert(doc->url());
         }
     }
-    clearDiagnosticsForStaleDocs({fpaths.begin(), fpaths.end()}, nullptr);
+    clearDiagnosticsForStaleDocs(fpaths, nullptr);
 }
 
 void DiagnosticsView::moveDiagnosticsSelection(bool forward)
