@@ -38,6 +38,15 @@
 #include <KTextEditor/View>
 #include <ktexteditor/cursor.h>
 
+Q_DECL_COLD_FUNCTION static void gitNotFoundMessage()
+{
+    Utils::showMessage(i18n("<b>git</b> not found. Git is needed to diff the documents. If git is already installed, make sure it is your PATH variable. See "
+                            "https://git-scm.com/downloads"),
+                       gitIcon(),
+                       i18n("Diff"),
+                       MessageType::Error);
+}
+
 DiffWidget *DiffWidgetManager::existingDiffWidgetForParams(KTextEditor::MainWindow *mw, const DiffParams &p)
 {
     const auto widgets = Utils::widgets(mw);
@@ -375,7 +384,7 @@ void DiffWidget::handleStyleChange(int newStyle)
         m_right->setVisible(false);
         openDiff(diff);
     } else {
-        qWarning() << "Unexpected diff style value: " << newStyle;
+        qWarning("Unexpected diff style value: %d", newStyle);
         Q_UNREACHABLE();
     }
 
@@ -494,7 +503,10 @@ void DiffWidget::applyDiff(const QString &diff, ApplyFlags flags)
     } else {
         args = QStringList{QStringLiteral("apply"), QStringLiteral("--index"), QStringLiteral("--cached"), file->fileName()};
     }
-    setupGitProcess(*git, m_params.workingDir, args);
+    if (!setupGitProcess(*git, m_params.workingDir, args)) {
+        gitNotFoundMessage();
+        return;
+    }
 
     connect(git, &QProcess::finished, this, [this, git, file](int exitCode, QProcess::ExitStatus es) {
         if (es != QProcess::NormalExit || exitCode != 0) {
@@ -524,7 +536,10 @@ void DiffWidget::runGitDiff()
     const int rf = m_right->firstVisibleBlockNumber();
 
     auto *git = new QProcess(this);
-    setupGitProcess(*git, workingDir, arguments);
+    if (!setupGitProcess(*git, workingDir, arguments)) {
+        gitNotFoundMessage();
+        return;
+    }
     connect(git, &QProcess::finished, this, [this, git, lf, rf](int, QProcess::ExitStatus) {
         const DiffParams params = m_params;
         clearData();
@@ -624,12 +639,7 @@ void DiffWidget::diffDocs(KTextEditor::Document *l, KTextEditor::Document *r)
     QProcess git;
     const QStringList args = diffDocsGitArgs(l, r);
     if (!setupGitProcess(git, qApp->applicationDirPath(), args)) {
-        Utils::showMessage(
-            i18n("<b>git</b> not found. Git is needed to diff the documents. If git is already installed, make sure it is your PATH variable. See "
-                 "https://git-scm.com/downloads"),
-            gitIcon(),
-            i18n("Diff"),
-            MessageType::Error);
+        gitNotFoundMessage();
         return;
     }
 
@@ -653,7 +663,12 @@ static void balanceHunkLines(QStringList &left, QStringList &right, int &lineA,
     }
 }
 
-static std::pair<Change, Change> inlineDiff(QStringView l, QStringView r)
+struct ChangePair {
+    Change left;
+    Change right;
+};
+
+static ChangePair inlineDiff(QStringView l, QStringView r)
 {
     auto sitl = l.begin();
     auto sitr = r.begin();
@@ -695,7 +710,7 @@ static std::pair<Change, Change> inlineDiff(QStringView l, QStringView r)
     Change cr;
     cr.pos = rStart;
     cr.len = rEnd - rStart;
-    return {cl, cr};
+    return {.left = cl, .right = cr};
 }
 
 // Struct representing a changed line in hunk
@@ -862,8 +877,8 @@ void DiffWidget::parseAndShowDiff(const QByteArray &raw)
         if (!match.hasMatch())
             continue;
 
-        const std::pair<uint, uint> oldRange = parseRange(match.captured(1));
-        const std::pair<uint, uint> newRange = parseRange(match.captured(2));
+        const DiffRange oldRange = parseRange(match.captured(1));
+        const DiffRange newRange = parseRange(match.captured(2));
         const QString headingLeft = QStringLiteral("@@ ") + match.captured(1) + match.captured(3) /* + QStringLiteral(" ") + srcFile*/;
         const QString headingRight = QStringLiteral("@@ ") + match.captured(2) + match.captured(3) /* + QStringLiteral(" ") + tgtFile*/;
 
@@ -878,11 +893,11 @@ void DiffWidget::parseAndShowDiff(const QByteArray &raw)
         hunkChangedLinesA.clear();
         hunkChangedLinesB.clear();
 
-        int srcLine = oldRange.first;
-        const int oldCount = oldRange.second;
+        int srcLine = oldRange.line;
+        const int oldCount = oldRange.count;
 
-        int tgtLine = newRange.first;
-        const int newCount = newRange.second;
+        int tgtLine = newRange.line;
+        const int newCount = newRange.count;
         maxLineNoFound = qMax(qMax(srcLine + oldCount, tgtLine + newCount), maxLineNoFound);
 
         for (int j = i + 1; j < text.size(); j++) {
@@ -901,7 +916,7 @@ void DiffWidget::parseAndShowDiff(const QByteArray &raw)
                 lineA++;
                 lineB++;
             } else if (l.startsWith(QLatin1Char('+'))) {
-                //                 qDebug() << "- line";
+                // qDebug("- line");
                 l = l.mid(1);
                 LineHighlight h;
                 h.line = lineB;
@@ -918,7 +933,7 @@ void DiffWidget::parseAndShowDiff(const QByteArray &raw)
                 lineB++;
             } else if (l.startsWith(QLatin1Char('-'))) {
                 l = l.mid(1);
-                //                 qDebug() << "+ line: " << l;
+                // qDebug("+ line: %ls", qUtf16Printable(l));
                 LineHighlight h;
                 h.line = lineA;
                 h.added = false;
@@ -1062,8 +1077,8 @@ void DiffWidget::parseAndShowDiffUnified(const QByteArray &raw)
         if (!match.hasMatch())
             continue;
 
-        const std::pair<uint, uint> oldRange = parseRange(match.captured(1));
-        const std::pair<uint, uint> newRange = parseRange(match.captured(2));
+        const DiffRange oldRange = parseRange(match.captured(1));
+        const DiffRange newRange = parseRange(match.captured(2));
         //         const QString headingLeft = QStringLiteral("@@ ") + match.captured(1) + match.captured(3) /* + QStringLiteral(" ") + srcFile*/;
         //         const QString headingRight = QStringLiteral("@@ ") + match.captured(2) + match.captured(3) /* + QStringLiteral(" ") + tgtFile*/;
 
@@ -1076,11 +1091,11 @@ void DiffWidget::parseAndShowDiffUnified(const QByteArray &raw)
         hunkChangedLinesA.clear();
         hunkChangedLinesB.clear();
 
-        int srcLine = oldRange.first;
-        const int oldCount = oldRange.second;
+        int srcLine = oldRange.line;
+        const int oldCount = oldRange.count;
 
-        int tgtLine = newRange.first;
-        const int newCount = newRange.second;
+        int tgtLine = newRange.line;
+        const int newCount = newRange.count;
         maxLineNoFound = qMax(qMax(srcLine + oldCount, tgtLine + newCount), maxLineNoFound);
 
         for (int j = i + 1; j < text.size(); j++) {
@@ -1095,7 +1110,7 @@ void DiffWidget::parseAndShowDiffUnified(const QByteArray &raw)
                 lineNo++;
                 //                 lineB++;
             } else if (l.startsWith(QLatin1Char('+'))) {
-                //                 qDebug() << "- line";
+                // qDebug("- line");
                 l = l.mid(1);
                 LineHighlight h;
                 h.line = lineNo;
