@@ -6,7 +6,6 @@
 */
 #include "gitdiff.h"
 
-#include <QDebug>
 #include <QRegularExpression>
 #include <QString>
 #include <QUrl>
@@ -55,7 +54,7 @@ public:
     /**
      * Returns the index of the line within the hunk
      *
-     * @param diffLineIdx the 0-based indes of the line in the diff
+     * @param diffLineIdx the 0-based index of the line in the diff
      *
      * @note assumes that the line is contained within the hunk
      * @note if the line is a header line, -1 is returned; otherwise the returned
@@ -142,13 +141,13 @@ static QString formatRange(uint start, uint count)
     return QString().setNum(start) + QLatin1Char(',') + QString().setNum(count);
 }
 
-std::pair<uint, uint> parseRange(const QString &range)
+DiffRange parseRange(const QString &range)
 {
     int commaPos = range.indexOf(QLatin1Char(','));
     if (commaPos > -1) {
-        return {QStringView(range).sliced(0, commaPos).toInt(), QStringView(range).sliced(commaPos + 1).toInt()};
+        return {QStringView(range).sliced(0, commaPos).toUInt(), QStringView(range).sliced(commaPos + 1).toUInt()};
     }
-    return {range.toInt(), 1};
+    return {range.toUInt(), 1};
 }
 
 /* Creates a hunk header line (starting with @@)
@@ -274,8 +273,8 @@ static std::vector<DiffHunk> parseHunks(VcsDiff &diff)
                     hunkLines << lines.next();
                 }
                 if (!CONFLICT_END_RE->match(lines.peekNext()).hasMatch()) {
-                    qWarning() << "Invalid diff format, end of file reached before conflict finished";
-                    qDebug() << diff.diff();
+                    qWarning("Invalid diff format, end of file reached before conflict finished");
+                    qDebug("%ls", qUtf16Printable(diff.diff()));
                     break;
                 }
             }
@@ -285,10 +284,10 @@ static std::vector<DiffHunk> parseHunks(VcsDiff &diff)
 
         // The number of filenames present in the diff should match the number
         // of hunks
-        ret.push_back(DiffHunk{.srcStart = oldRange.first,
-                               .srcCount = oldRange.second,
-                               .tgtStart = newRange.first,
-                               .tgtCount = newRange.second,
+        ret.push_back(DiffHunk{.srcStart = oldRange.line,
+                               .srcCount = oldRange.count,
+                               .tgtStart = newRange.line,
+                               .tgtCount = newRange.count,
                                .headingLineIdx = firstLineIdx,
                                .srcFile = curSrcFileName,
                                .tgtFile = curTgtFileName,
@@ -302,8 +301,7 @@ static std::vector<DiffHunk> parseHunks(VcsDiff &diff)
         if (ret.size() > 0 && ret.back().lines.size() > 0) {
             ret.back().lines.pop_back();
         } else {
-            qWarning() << "Failed to parse a diff, produced no hunks";
-            qDebug() << "Failed diff:" << diff.diff();
+            qWarning("Failed to parse a diff, produced no hunks");
         }
     }
 
