@@ -77,6 +77,8 @@
 
 #ifdef WITH_DBUS
 #include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusReply>
 #endif
 
 #include <urlinfo.h>
@@ -123,6 +125,8 @@ static bool insideTerminal = false;
 static KateAppAdaptor *adaptor = nullptr;
 #endif
 
+static bool ignoreUnixSignals = false;
+
 /**
  * singleton instance pointer
  */
@@ -212,7 +216,7 @@ void KateApp::initPreApplicationCreation(bool detach)
         sysctl(mib, 2, &path[0], &len, nullptr, 0);
         path.removeLast();
         QByteArray p = qgetenv("PATH");
-        qDebug() << "Adding '" << path << "' to existing PATH:" << p;
+        qDebug("Adding '%s' to existing PATH: %s", path.constData(), p.constData());
         path.append(':').append(p);
         qputenv("PATH", p);
     }
@@ -301,6 +305,7 @@ KateApp::KateApp(const QCommandLineParser &args, const ApplicationMode mode, con
 
 KateApp::~KateApp()
 {
+    qCDebug(LOG_KATE, "%s", Q_FUNC_INFO);
     // we want no auto saving during application closing, we handle that explicitly
     KateSessionManager::AutoSaveBlocker blocker(sessionManager());
 
@@ -328,18 +333,43 @@ KateApp *KateApp::self()
     return appSelf;
 }
 
-void KateApp::fillAuthorsAndCredits(KAboutData &aboutData)
+void KateApp::initPostApplicationCreation(KAboutData &aboutData)
 {
-    aboutData.addAuthor(i18n("Christoph Cullmann"), i18n("Maintainer"), QStringLiteral("cullmann@kde.org"), QStringLiteral("https://cullmann.io"));
+#ifdef WITH_DBUS
+    // on wayland: init token if we are launched by Konsole and have none
+    if (KWindowSystem::isPlatformWayland() && qEnvironmentVariable("XDG_ACTIVATION_TOKEN").isEmpty() && QDBusConnection::sessionBus().interface()) {
+        // can we ask Konsole for a token?
+        const auto konsoleService = qEnvironmentVariable("KONSOLE_DBUS_SERVICE");
+        const auto konsoleSession = qEnvironmentVariable("KONSOLE_DBUS_SESSION");
+        const auto konsoleActivationCookie = qEnvironmentVariable("KONSOLE_DBUS_ACTIVATION_COOKIE");
+        if (!konsoleService.isEmpty() && !konsoleSession.isEmpty() && !konsoleActivationCookie.isEmpty()) {
+            // we ask the current shell session
+            QDBusMessage m =
+                QDBusMessage::createMethodCall(konsoleService, konsoleSession, QStringLiteral("org.kde.konsole.Session"), QStringLiteral("activationToken"));
+
+            // use the cookie from the environment
+            m.setArguments({konsoleActivationCookie});
+
+            // get the token, if possible and export it to environment for later use
+            const auto tokenAnswer = QDBusConnection::sessionBus().call(m);
+            if (tokenAnswer.type() == QDBusMessage::ReplyMessage && !tokenAnswer.arguments().isEmpty()) {
+                const auto token = tokenAnswer.arguments().first().toString();
+                if (!token.isEmpty()) {
+                    qputenv("XDG_ACTIVATION_TOKEN", token.toUtf8());
+                }
+            }
+        }
+    }
+#endif
+
+    // fill author data
+    aboutData.addAuthor(i18n("Christoph Cullmann"), i18n("Maintainer"), QStringLiteral("cullmann@kde.org"), QStringLiteral("https://cullmann.dev"));
     aboutData.addAuthor(i18n("Dominik Haumann"), i18n("Core Developer"), QStringLiteral("dhaumann@kde.org"));
     aboutData.addAuthor(i18n("Sven Brauch"), i18n("Developer"), QStringLiteral("mail@svenbrauch.de"));
     aboutData.addAuthor(i18n("Kåre Särs"), i18n("Developer"), QStringLiteral("kare.sars@iki.fi"));
     aboutData.addAuthor(i18n("Waqar Ahmed"), i18n("Core Developer"), QStringLiteral("waqar.17a@gmail.com"));
-    aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"), QStringLiteral("https://www.alweb.dk"));
-    aboutData.addAuthor(i18n("Joseph Wenninger"),
-                        i18n("Core Developer"),
-                        QStringLiteral("jowenn@kde.org"),
-                        QStringLiteral("http://stud3.tuwien.ac.at/~e9925371"));
+    aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"));
+    aboutData.addAuthor(i18n("Joseph Wenninger"), i18n("Core Developer"), QStringLiteral("jowenn@kde.org"));
     aboutData.addAuthor(i18n("Hamish Rodda"), i18n("Core Developer"), QStringLiteral("rodda@kde.org"));
     aboutData.addAuthor(i18n("Alexander Neundorf"), i18n("Developer"), QStringLiteral("neundorf@kde.org"));
     aboutData.addAuthor(i18n("Waldo Bastian"), i18n("The cool buffersystem"), QStringLiteral("bastian@kde.org"));
@@ -358,11 +388,9 @@ void KateApp::fillAuthorsAndCredits(KAboutData &aboutData)
                         i18n("Python Plugin Developer"),
                         QStringLiteral("goinnn@gmail.com"),
                         QStringLiteral("https://github.com/goinnn/"));
-    aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"),
-                        i18n("QA and Scripting"),
-                        QStringLiteral("oss@senarclens.eu"),
-                        QStringLiteral("http://find-santa.eu/"));
+    aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"), i18n("QA and Scripting"), QStringLiteral("oss@senarclens.eu"));
 
+    // fill credits
     aboutData.addCredit(i18n("Tyson Tan"),
                         i18n("Designer of Kate's mascot 'Kate the Cyber Woodpecker'"),
                         QString(),
@@ -399,8 +427,9 @@ bool KateApp::init()
     KSignalHandler::self()->watchSignal(SIGINT);
     KSignalHandler::self()->watchSignal(SIGTERM);
     connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
-        if (signal == SIGINT || signal == SIGTERM) {
-            printf("Shutting down...\n");
+        if ((signal == SIGINT || signal == SIGTERM) && !ignoreUnixSignals) {
+            const char *str = signal == SIGINT ? "SIGINT" : "SIGTERM";
+            qCDebug(LOG_KATE, "signal received: %s, Shutting down...", str);
             quit();
         }
     });
@@ -538,14 +567,13 @@ bool KateApp::startupKate()
 
     // handle stdin input
     if (m_args.isSet(QStringLiteral("stdin"))) {
-        QFile input;
-        input.open(stdin, QIODevice::ReadOnly);
-        auto decoder = QStringDecoder(codec_name.toUtf8().constData());
-        QString text = decoder.isValid() ? decoder.decode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
-
-        // normalize line endings, to e.g. catch issues with \r\n on Windows
-        text.replace(QRegularExpression(QStringLiteral("\r\n?")), QStringLiteral("\n"));
-
+        QString text;
+        if (QFile input; input.open(stdin, QIODevice::ReadOnly)) {
+            auto decoder = QStringDecoder(codec_name.toUtf8().constData());
+            text = decoder.isValid() ? decoder.decode(input.readAll()) : QString::fromLocal8Bit(input.readAll());
+            // normalize line endings, to e.g. catch issues with \r\n on Windows
+            text.replace(QRegularExpression(QStringLiteral("\r\n?")), QStringLiteral("\n"));
+        }
         openInput(text, codec_name);
     } else if (doc) {
         activeKateMainWindow()->viewManager()->activateView(doc);
@@ -559,10 +587,13 @@ void KateApp::shutdownKate(KateMainWindow *win)
     // we want no auto saving during application closing, we handle that explicitly
     KateSessionManager::AutoSaveBlocker blocker(sessionManager());
 
-    if (!win->queryClose_internal()) {
+    if (win && !win->queryClose_internal()) {
         return;
     }
 
+    //  we are ready to quit, ignore any unix signals now to avoid incorrect session save. BUG: 508494
+    setIgnoreSignals();
+
     qCDebug(LOG_KATE, "KateApp::%s save session", __func__);
     sessionManager()->saveActiveSession(true);
 
@@ -911,6 +942,11 @@ bool KateApp::isInsideTerminal()
     return insideTerminal;
 }
 
+void KateApp::setIgnoreSignals()
+{
+    ignoreUnixSignals = true;
+}
+
 qint64 KateApp::lastActivationChange() const
 {
 #if HAVE_X11
