@@ -51,11 +51,23 @@ public:
      */
     static void initPreApplicationCreation(bool detach);
 
+    /**
+     * Try to get XDG_ACTIVATION_TOKEN if possible from Konsole.
+     * Fill in the authors and credits for the application.
+     * Use by Kate & KWrite
+     */
+    static void initPostApplicationCreation(KAboutData &aboutData);
+
     /**
      * Was the application started inside a terminal?
      */
     static bool isInsideTerminal();
 
+    /**
+     * Ignore unix signals
+     */
+    static void setIgnoreSignals();
+
     /**
      *  Are we full featured Kate or the simplified KWrite?
      */
@@ -96,12 +108,6 @@ public:
         return mode() == KateApp::ApplicationKWrite;
     }
 
-    /**
-     * Fill in the authors and credits for the application.
-     * Use by Kate & KWrite
-     */
-    static void fillAuthorsAndCredits(KAboutData &aboutData);
-
     /**
      * get kate inited
      * @return false, if application should exit
@@ -402,7 +408,7 @@ public Q_SLOTS:
     }
 
     /**
-     * last time some QEvent::ActivationChange occured, negated if no windows on the current active desktop
+     * last time some QEvent::ActivationChange occurred, negated if no windows on the current active desktop
      * used to determine which instance to reuse, if we have multiple
      */
     qint64 lastActivationChange() const;
@@ -429,6 +435,12 @@ Q_SIGNALS:
      */
     void configurationChanged();
 
+    /**
+     * Emitted when the pin status of a document changes. This is defined here because its used
+     * in plugins
+     */
+    void documentPinStatusChanged(KTextEditor::Document *document);
+
 protected:
     /**
      * Event filter for QApplication to handle mac os like file open
@@ -495,7 +507,7 @@ private:
 #endif
 
     /**
-     * last time some QEvent::ActivationChange occured
+     * last time some QEvent::ActivationChange occurred
      * used to determine which instance to reuse, if we have multiple
      */
     qint64 m_lastActivationChange;
