@@ -94,6 +94,7 @@ public:
     void slotDocumentClose();
     void slotDocumentClose(KTextEditor::Document *document);
     void slotRestoreLastClosedDocument();
+    void slotOpenNextPinnedDocument();
 
     void setActiveSpace(KateViewSpace *vs);
 
@@ -318,7 +319,7 @@ public:
     void replugActiveView();
 
     /**
-     * Toogle the orientation of current split view
+     * Toggle the orientation of current split view
      */
     void toggleSplitterOrientation();
 
