@@ -6,12 +6,10 @@
 */
 
 #include "katequickopen.h"
+#include "katemainwindow.h"
 #include "katequickopenmodel.h"
 #include "quickdialog.h"
 
-#include "katemainwindow.h"
-#include "kateviewmanager.h"
-
 #include <KTextEditor/Document>
 #include <ktexteditor/view.h>
 
@@ -31,9 +29,9 @@
 #include <QToolBar>
 #include <QTreeView>
 
+#include <QGraphicsEffect>
 #include <drawing_utils.h>
 #include <kfts_fuzzy_match.h>
-#include <qgraphicseffect.h>
 
 class QuickOpenFilterProxyModel final : public QSortFilterProxyModel
 {
@@ -82,7 +80,7 @@ protected:
             }
         }
 
-        const QString &name = sm->idxToFileName(sourceRow);
+        QStringView name = sm->idxToFileName(sourceRow);
 
         int score = 0;
         bool res;
@@ -90,14 +88,14 @@ protected:
         if (fileNameMatchPattern.isEmpty()) {
             res = true;
         } else {
-            res = filterByName(QStringView(name.data(), name.size()), fileNameMatchPattern, score);
+            res = filterByName(name, fileNameMatchPattern, score);
         }
 
         // only match file path if needed
         if (matchPath && res) {
             int scorep = 0;
             QStringView path{sm->idxToFilePath(sourceRow)};
-            bool resp = filterByPath(path, QStringView(pattern.data(), pattern.size()), scorep);
+            bool resp = filterByPath(path, pattern, scorep);
             score += scorep;
             res = resp;
             // zero out the score if didn't match
@@ -118,7 +116,7 @@ protected:
             }
         }
         //         if (res && pattern == QStringLiteral(""))
-        //             qDebug() << score << ", " << name << "==================== END\n";
+        //             qDebug("%d, %ls==================== END\n", score, qUtf16Printable(name));
 
         sm->setScoreForIndex(sourceRow, score);
 
@@ -308,8 +306,8 @@ KateQuickOpen::KateQuickOpen(KateMainWindow *mainWindow)
         if (didFilter) {
             m_styleDelegate->setFilterString(text);
             m_listView->viewport()->update();
-            reselectFirst();
         }
+        reselectFirst();
     });
 
     setHidden(true);
@@ -381,7 +379,7 @@ void KateQuickOpen::reselectFirst()
 {
     int first = 0;
     const QAbstractItemModel *model = m_listView->model();
-    if (m_mainWindow->viewManager()->views().size() > 1 && model->rowCount() > 1 && m_inputLine->text().isEmpty()) {
+    if (m_mainWindow->views().size() > 1 && model->rowCount() > 1 && m_inputLine->text().isEmpty()) {
         first = 1;
     }
 
@@ -404,57 +402,61 @@ void KateQuickOpen::updateState()
 void KateQuickOpen::slotReturnPressed()
 {
     // save current position before opening new url for location history
-    KateViewManager *vm = m_mainWindow->viewManager();
-    if (KTextEditor::View *v = vm->activeView()) {
-        vm->addPositionToHistory(v->document()->url(), v->cursorPosition());
+    if (KTextEditor::View *v = m_mainWindow->activeView()) {
+        m_mainWindow->addPositionToHistory(v->document()->url(), v->cursorPosition());
     }
 
     // either get view via document pointer or url
     const QModelIndex index = m_listView->currentIndex();
-    KTextEditor::View *view = nullptr;
-    if (auto *doc = index.data(KateQuickOpenModel::Document).value<KTextEditor::Document *>()) {
-        view = m_mainWindow->activateView(doc);
-    } else {
-        QFileInfo file(index.data(Qt::UserRole).toUrl().toLocalFile());
-        // If the file is a directory, we're likely opening a project
-        if (file.isDir()) {
-            // Make sure projectview exists, then invoke switchToProject method with the directory we have
-            QObject *projectView = m_mainWindow->pluginView(QStringLiteral("kateprojectplugin"));
-            if (projectView) {
-                QMetaObject::invokeMethod(projectView, "switchToProject", Qt::DirectConnection, QDir(index.data(Qt::UserRole).toUrl().toLocalFile()));
-                QWidget *toolview = m_mainWindow->toolviewForName(QStringLiteral("kate_mdi_focus_toolview_projects"));
-                if (toolview) {
-                    m_mainWindow->showToolView(toolview);
-                    toolview->setFocus();
-                }
-            }
-        } else {
-            view = m_mainWindow->wrapper()->openUrl(index.data(Qt::UserRole).toUrl());
+    KTextEditor::View *view = [index, this]() -> KTextEditor::View * {
+        if (!index.isValid()) {
+            return nullptr;
         }
-    }
+        if (auto *doc = index.data(KateQuickOpenModel::Document).value<KTextEditor::Document *>()) {
+            return m_mainWindow->activateView(doc);
+        } else {
+            QFileInfo file(index.data(Qt::UserRole).toUrl().toLocalFile());
+            // If the file is a directory, we're likely opening a project
+            if (file.isDir()) {
+                // Make sure projectview exists, then invoke switchToProject method with the directory we have
+                QObject *projectView = m_mainWindow->pluginView(QStringLiteral("kateprojectplugin"));
+                if (projectView) {
+                    QMetaObject::invokeMethod(projectView, "switchToProject", Qt::DirectConnection, QDir(index.data(Qt::UserRole).toUrl().toLocalFile()));
+                    QWidget *toolview = m_mainWindow->toolviewForName(QStringLiteral("kate_mdi_focus_toolview_projects"));
+                    if (toolview) {
+                        m_mainWindow->showToolView(toolview);
+                        toolview->setFocus();
+                    }
+                }
+            } else {
+                return m_mainWindow->wrapper()->openUrl(index.data(Qt::UserRole).toUrl());
+            }
+        }
+        return nullptr;
+    }();
 
     const QStringList strs = m_inputLine->text().split(QLatin1Char(':'));
     if (view && strs.count() > 1) {
-        // helper to convert String => Number
-        std::function<int(const QString &)> stringToInt = [](const QString &s) {
-            bool ok = false;
-            const int num = s.toInt(&ok);
-            return ok ? num : -1;
-        };
-        KTextEditor::Cursor cursor = KTextEditor::Cursor::invalid();
+        // convert strings to cursor
+        const auto cursor = [](const QStringList &strs) -> KTextEditor::Cursor {
+            if (strs.size() > 1) {
+                bool ok = false;
+                int line = strs.at(1).toInt(&ok);
+                if (ok) {
+                    if (strs.size() > 2) {
+                        int column = strs.at(2).toInt(&ok);
+                        if (ok) {
+                            return {line - 1, column - 1};
+                        }
+                    }
+                    return {line - 1, 0};
+                }
+            }
+            return KTextEditor::Cursor::invalid();
+        }(strs);
 
-        // try to get line
-        const int line = stringToInt(strs.at(1));
-        cursor.setLine(line - 1);
-
-        // if line is valid, try to see if we have column available as well
-        if (line > -1 && strs.count() > 2) {
-            const int col = stringToInt(strs.at(2));
-            cursor.setColumn(col - 1);
-        }
-
-        // do we have valid line at least?
-        if (line > -1) {
+        // jump to position if we have a valid cursor
+        if (cursor.isValid()) {
             view->setCursorPosition(cursor);
         }
     }
@@ -466,7 +468,7 @@ void KateQuickOpen::slotReturnPressed()
 
     // store the new position in location history
     if (view) {
-        vm->addPositionToHistory(view->document()->url(), view->cursorPosition());
+        m_mainWindow->addPositionToHistory(view->document()->url(), view->cursorPosition());
     }
 }
 
